@@ -8,6 +8,9 @@
 #ifndef BOOST_THREAD_EXECUTORS_SCHEDULED_THREAD_POOL_HPP
 #define BOOST_THREAD_EXECUTORS_SCHEDULED_THREAD_POOL_HPP
 
+#include <boost/thread/detail/config.hpp>
+#if defined BOOST_THREAD_PROVIDES_FUTURE_CONTINUATION && defined BOOST_THREAD_PROVIDES_EXECUTORS && defined BOOST_THREAD_USES_MOVE
+
 #include <boost/thread/executors/detail/scheduled_executor_base.hpp>
 
 namespace boost
@@ -46,4 +49,5 @@ using executors::scheduled_thread_pool;
 
 } //end boost
 #endif
+#endif
 
